==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/plugins/style/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.style_dlg',{
title:"CSS\u7DE8\u96C6",
apply:"\u9069\u7528",
text_tab:"\u6587\u5B57",
background_tab:"\u80CC\u666F",
block_tab:"\u30D6\u30ED\u30C3\u30AF",
box_tab:"\u30DC\u30C3\u30AF\u30B9",
border_tab:"\u67A0\u7DDA",
list_tab:"\u30EA\u30B9\u30C8",
positioning_tab:"\u30DD\u30B8\u30B7\u30E7\u30F3",
text_props:"Text",
text_font:"\u30D5\u30A9\u30F3\u30C8",
text_size:"\u30B5\u30A4\u30BA",
text_weight:"\u592A\u3055",
text_style:"\u30B9\u30BF\u30A4\u30EB",
text_variant:"\u5909\u5F62",
text_lineheight:"\u884C\u9AD8\u3055",
text_case:"\u5927\u6587\u5B57/\u5C0F\u6587\u5B57",
text_color:"\u8272",
text_decoration:"\u88C5\u98FE",
text_overline:"\u4E0A\u7DDA",
text_underline:"\u4E0B\u7DDA",
text_striketrough:"\u6253\u6D88\u3057\u7DDA",
text_blink:"\u70B9\u6EC5",
text_none:"\u306A\u3057",
background_color:"\u80CC\u666F\u8272",
background_image:"\u80CC\u666F\u753B\u50CF",
background_repeat:"\u7E70\u308A\u8FD4\u3057",
background_attachment:"Attachment",
background_hpos:"\u6C34\u5E73\u4F4D\u7F6E",
background_vpos:"\u5782\u76F4\u4F4D\u7F6E",
block_wordspacing:"\u5358\u8A9E\u611F\u899A",
block_letterspacing:"\u6587\u5B57\u9593\u9694",
block_vertical_alignment:"\u5782\u76F4\u914D\u7F6E",
block_text_align:"\u6C34\u5E73\u914D\u7F6E",
block_text_indent:"\u30A4\u30F3\u30C7\u30F3\u30C8",
block_whitespace:"\u7A7A\u767D\u6587\u5B57",
block_display:"\u30C7\u30A3\u30B9\u30D7\u30EC\u30A4",
box_width:"\u5E45",
box_height:"\u9AD8\u3055",
box_float:"\u56DE\u308A\u8FBC\u307F",
box_clear:"\u56DE\u308A\u8FBC\u307F\u89E3\u9664",
padding:"\u30D1\u30C7\u30A3\u30F3\u30B0",
same:"\u5168\u3066\u540C\u3058\u306B\u3059\u308B",
top:"\u4E0A",
right:"\u53F3",
bottom:"\u4E0B",
left:"\u5DE6",
margin:"\u30DE\u30FC\u30B8\u30F3",
style:"\u30B9\u30BF\u30A4\u30EB",
width:"\u5E45",
height:"\u9AD8\u3055",
color:"\u8272",
list_type:"\u30DE\u30FC\u30AB\u30FC\u7A2E\u985E",
bullet_image:"\u30DE\u30FC\u30AB\u30FC\u753B\u50CF",
position:"\u30DE\u30FC\u30AB\u30FC\u8868\u793A\u4F4D\u7F6E",
positioning_type:"\u914D\u7F6E\u65B9\u6CD5",
visibility:"\u8868\u793A",
zindex:"Z-Index",
overflow:"\u30AA\u30FC\u30D0\u30FC\u30D5\u30ED\u30FC",
placement:"\u4F4D\u7F6E",
clip:"\u5207\u308A\u629C\u304D"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/style/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.style_dlg',{
title:"CSS\u7DE8\u96C6",
apply:"\u9069\u7528",
text_tab:"\u6587\u5B57",
background_tab:"\u80CC\u666F",
block_tab:"\u30D6\u30ED\u30C3\u30AF",
box_tab:"\u30DC\u30C3\u30AF\u30B9",
border_tab:"\u67A0\u7DDA",
list_tab:"\u30EA\u30B9\u30C8",
positioning_tab:"\u30DD\u30B8\u30B7\u30E7\u30F3",
text_props:"Text",
text_font:"\u30D5\u30A9\u30F3\u30C8",
text_size:"\u30B5\u30A4\u30BA",
text_weight:"\u592A\u3055",
text_style:"style\u5C5E\u6027",
text_variant:"\u5909\u5F62",
text_lineheight:"\u884C\u9AD8\u3055",
text_case:"\u5927\u6587\u5B57/\u5C0F\u6587\u5B57",
text_color:"\u8272",
text_decoration:"\u88C5\u98FE",
text_overline:"\u4E0A\u7DDA",
text_underline:"\u4E0B\u7DDA",
text_striketrough:"\u6253\u6D88\u3057\u7DDA",
text_blink:"\u70B9\u6EC5",
text_none:"\u306A\u3057",
background_color:"\u80CC\u666F\u8272",
background_image:"\u80CC\u666F\u753B\u50CF",
background_repeat:"\u7E70\u308A\u8FD4\u3057",
background_attachment:"Attachment",
background_hpos:"\u6C34\u5E73\u4F4D\u7F6E",
background_vpos:"\u5782\u76F4\u4F4D\u7F6E",
block_wordspacing:"\u5358\u8A9E\u611F\u899A",
block_letterspacing:"\u6587\u5B57\u9593\u9694",
block_vertical_alignment:"\u5782\u76F4\u914D\u7F6E",
block_text_align:"\u6C34\u5E73\u914D\u7F6E",
block_text_indent:"\u30A4\u30F3\u30C7\u30F3\u30C8",
block_whitespace:"\u7A7A\u767D\u6587\u5B57",
block_display:"\u30C7\u30A3\u30B9\u30D7\u30EC\u30A4",
box_width:"\u5E45",
box_height:"\u9AD8\u3055",
box_float:"\u56DE\u308A\u8FBC\u307F",
box_clear:"\u56DE\u308A\u8FBC\u307F\u89E3\u9664",
padding:"\u30D1\u30C7\u30A3\u30F3\u30B0",
same:"\u5168\u3066\u540C\u3058\u306B\u3059\u308B",
top:"\u4E0A",
right:"\u53F3",
bottom:"\u4E0B",
left:"\u5DE6",
margin:"\u30DE\u30FC\u30B8\u30F3",
style:"style\u5C5E\u6027",
width:"\u5E45",
height:"\u9AD8\u3055",
color:"\u8272",
list_type:"\u30DE\u30FC\u30AB\u30FC\u7A2E\u985E",
bullet_image:"\u30DE\u30FC\u30AB\u30FC\u753B\u50CF",
position:"\u30DE\u30FC\u30AB\u30FC\u8868\u793A\u4F4D\u7F6E",
positioning_type:"\u914D\u7F6E\u65B9\u6CD5",
visibility:"\u8868\u793A",
zindex:"Z-Index",
overflow:"\u30AA\u30FC\u30D0\u30FC\u30D5\u30ED\u30FC",
placement:"\u4F4D\u7F6E",
clip:"\u5207\u308A\u629C\u304D"
});
